#!/bin/bash
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 08-02-2007
# source location  : http://switch.dl.sourceforge.net/sourceforge/denyhosts/DenyHosts-2.6.tar.gz 

NAME=denyhosts
VERSION=2.6
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-48.1}
TMP=${TMP:-/tmp}
PKG=$TMP/package-$NAME
CWD=`pwd`
PYTHON=/usr/bin/python

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf DenyHosts-$VERSION
  if [ -f DenyHosts-$VERSION.tar.gz ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/DenyHosts-$VERSION.tar.gz ]; then
          echo "Relocating source file to $TMP"
          cp $CWD/DenyHosts-$VERSION.tar.gz $TMP/
  else
	  wget -c http://switch.dl.sourceforge.net/sourceforge/denyhosts/DenyHosts-2.6.tar.gz
  fi
tar xzf DenyHosts-$VERSION.tar.gz

cd DenyHosts-$VERSION

# Make sure ownerships and permissions are sane:
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Configure:
$PYTHON setup.py build

# Build and install:
$PYTHON setup.py install --root=$PKG --prefix=/usr

# Relocate files
mkdir -p $PKG/etc/rc.d
mv $PKG/usr/share/denyhosts/denyhosts.cfg-dist $PKG/etc/denyhosts.cfg.new
sed -i -e 's/SECURE_LOG = \/var\/log\/secure/#SECURE_LOG = \/var\/log\/secure/g' $PKG/etc/denyhosts.cfg.new
sed -i -e 's/#SECURE_LOG = \/var\/log\/messages/SECURE_LOG = \/var\/log\/messages/g' $PKG/etc/denyhosts.cfg.new
mkdir -p $PKG/etc/rc.d/desc.d
cat << "EOF" > $PKG/etc/rc.d/desc.d/denyhosts.txt
denyhosts:Scan ssh server logs and block hosts
EOF
cat << "EOF" > $PKG/etc/rc.d/rc.denyhosts
#!/bin/bash
#
# Start/Stop Denyhost daemon
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 08-02-2007

NAME=DenyHosts
PROGRAM=/usr/bin/denyhosts.py

start()
{
  if [ ! -f /var/lock/subsys/denyhosts ]; then
   $PROGRAM --daemon --config=/etc/denyhosts.cfg
  else
   echo "$NAME is already running"
  fi
}

stop()
{
  if [ -f /var/lock/subsys/denyhosts ]; then
   kill -9 $(cat /var/lock/subsys/denyhosts)
   rm /var/lock/subsys/denyhosts
  else
   echo "$NAME isn't running"
 fi
}

restart()
{
  stop
  sleep 1
  start
}

case "$1" in
'start')
  start
  ;;
'stop')
  stop
  ;;
'restart')
  restart
  ;;
*)
  echo "Usage $(basename $0): start|stop|restart"
esac
EOF

chmod +x $PKG/etc/rc.d/rc.denyhosts

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

DOCS="CHANGELOG.txt LICENSE.txt MANIFEST.in PKG-INFO README.txt"
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

chmod 644 $PKG/usr/doc/$NAME-$VERSION/PKG-INFO

# 
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

mkdir -p $PKG/install

echo "$NAME: denyhosts (Scan ssh server logs and block hosts)
$NAME:
$NAME: DenyHosts is a script intended to help Linux system administrators
$NAME: thwart ssh server attacks. DenyHosts scans an ssh server log,
$NAME: updates /etc/hosts.deny after a configurable number of failed
$NAME: attempts from a rogue host is determined, and alerts the
$NAME: administrator of any suspicious logins.
$NAME:
$NAME: Compiled for Zenwalk" > $PKG/install/slack-desc

# create doinst.sh file
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}
config etc/denyhosts.cfg" > $PKG/install/doinst.sh


#
# real packaging work:
#
cd $TMP/package-$NAME
makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
cd $TMP
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
echo "python" > $NAME-$VERSION-$ARCH-$BUILD.dep

